@@ -1,8 +1,9 @@
 use Test;
-BEGIN { plan tests => 5 };
-use WWW::ShopBot qw/list_drivers/;
+BEGIN { plan tests => 6 };
+use WWW::ShopBot qw/list_drivers list_drivers_paths/;
 ok(1);
-ok(join(q//, list_drivers), '_test_test::_test');
+ok(join(q//, list_drivers), qr/_test::_test/);
+ok(join(q//, list_drivers_paths), qr,WWW/ShopBot/_test.pm,);
 
 $bot = new WWW::ShopBot(drivers => [ '_test', ]);
 push @pool,
